@@ -1,5 +1,7 @@
 from typing import List
 
+import requests
+
 from redash_python.services import (
     AlertsService,
     BaseService,
@@ -12,7 +14,7 @@ from redash_python.services import (
     UsersService,
 )
 
-version = "0.1.2"
+version = "0.1.5"
 
 
 class Redash:
@@ -59,6 +61,14 @@ class Redash:
         self.post = self.__base.post
         self.delete = self.__base.delete
 
+    def test_credentials(self):
+        """Test whether current credentials are valid"""
+        try:
+            response = self.get("/api/session")
+            return True
+        except requests.exceptions.HTTPError:
+            return False
+
     def __dir__(self) -> List[str]:
         return self.services + ["get", "post", "put", "delete"]
 
