@@ -39,6 +39,11 @@ class DashboardsService(
             query = widget.visualization.query
             self.__base.post(f"/api/queries/{query.id}/results", {"max_age": 0})
 
+    def share(self, dashboard_id: int) -> str:
+        """Share a dashboard with a group"""
+        response = self.__base.post(f"{self.endpoint}/{dashboard_id}/share", {})
+        return response.public_url
+
     def create_widget(
         self,
         dashboard_id: int,
